JBossWS SVN: r15681 - thirdparty/cxf/branches/cxf-2.2.12/rt/core/src/main/java/org/apache/cxf/transport/http.
by jbossws-commits@lists.jboss.org
Author: mmusaji
Date: 2012-02-17 08:24:04 -0500 (Fri, 17 Feb 2012)
New Revision: 15681
Modified:
thirdparty/cxf/branches/cxf-2.2.12/rt/core/src/main/java/org/apache/cxf/transport/http/WSDLQueryHandler.java
Log:
[JBPAPP-8011] - Fix to allow soap12 addresses to be rewritten successfully
Modified: thirdparty/cxf/branches/cxf-2.2.12/rt/core/src/main/java/org/apache/cxf/transport/http/WSDLQueryHandler.java
===================================================================
--- thirdparty/cxf/branches/cxf-2.2.12/rt/core/src/main/java/org/apache/cxf/transport/http/WSDLQueryHandler.java 2012-02-17 12:27:21 UTC (rev 15680)
+++ thirdparty/cxf/branches/cxf-2.2.12/rt/core/src/main/java/org/apache/cxf/transport/http/WSDLQueryHandler.java 2012-02-17 13:24:04 UTC (rev 15681)
@@ -311,11 +311,8 @@
for (Element el : elementList) {
String name = el.getAttribute("name");
if (name.equals(ei.getName().getLocalPart())) {
- Element soapAddress = DOMUtils.findAllElementsByTagNameNS(el,
- "http://schemas.xmlsoap.org/wsdl/soap/",
- "address")
- .iterator().next();
- soapAddress.setAttribute("location", base);
+ rewriteAddress(base, el, "http://schemas.xmlsoap.org/wsdl/soap/");
+ rewriteAddress(base, el, "http://schemas.xmlsoap.org/wsdl/soap12/");
}
}
}
@@ -327,6 +324,14 @@
//likely not DOM level 3
}
}
+
+ private void rewriteAddress(String base, Element el, String soapNS) {
+ List<Element> sadEls = DOMUtils.findAllElementsByTagNameNS(el,soapNS,
+ "address");
+ for (Element soapAddress : sadEls) {
+ soapAddress.setAttribute("location", base);
+ }
+ }
static String resolveWithCatalogs(OASISCatalogManager catalogs, String start, String base) {
if (catalogs == null) {
12 years, 10 months
JBossWS SVN: r15680 - in stack/cxf/branches/jbossws-cxf-4.0.x: modules/testsuite and 3 other directories.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 07:27:21 -0500 (Fri, 17 Feb 2012)
New Revision: 15680
Added:
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
Removed:
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jndi.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties
Modified:
stack/cxf/branches/jbossws-cxf-4.0.x/
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/pom.xml
stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
Log:
Merged revisions 15675 via svnmerge from
https://svn.jboss.org/repos/jbossws/stack/cxf/trunk
.......
r15675 | ropalka | 2012-02-17 12:32:54 +0100 (Fri, 17 Feb 2012) | 1 line
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
.......
Property changes on: stack/cxf/branches/jbossws-cxf-4.0.x
___________________________________________________________________
Modified: svnmerge-integrated
- https://svn.jboss.org/repos/jbossws/stack/cxf/trunk:1-15635,15658,15668
+ https://svn.jboss.org/repos/jbossws/stack/cxf/trunk:1-15635,15658,15668,1...
Modified: svn:mergeinfo
- /stack/cxf/branches/asoldano:14032-14050,14068
/stack/cxf/trunk:15658,15668
+ /stack/cxf/branches/asoldano:14032-14050,14068
/stack/cxf/trunk:15658,15668,15675
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Modified: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/pom.xml
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/pom.xml 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/pom.xml 2012-02-17 12:27:21 UTC (rev 15680)
@@ -135,6 +135,7 @@
<!-- copy etc files -->
<testResource>
<directory>src/test/etc</directory>
+ <filtering>true</filtering>
</testResource>
<!-- copy handler definitions -->
<testResource>
@@ -265,10 +266,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -359,10 +356,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -1159,11 +1152,6 @@
</exclusions>
</dependency>
<dependency>
- <groupId>org.jboss.naming</groupId>
- <artifactId>jnp-client</artifactId>
- <version>5.0.5.Final</version>
- </dependency>
- <dependency>
<groupId>org.jboss.ejb3</groupId>
<artifactId>jboss-ejb3-ext-api</artifactId>
<version>2.0.0-beta-1</version>
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Copied: stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (from rev 15675, stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties)
===================================================================
--- stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/branches/jbossws-cxf-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties 2012-02-17 12:27:21 UTC (rev 15680)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
12 years, 10 months
JBossWS SVN: r15679 - in stack/native/branches/jbossws-native-4.0.x: modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client and 4 other directories.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 07:07:13 -0500 (Fri, 17 Feb 2012)
New Revision: 15679
Added:
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/server.jndi.properties
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
Removed:
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jndi.properties
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties
Modified:
stack/native/branches/jbossws-native-4.0.x/
stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceImpl.java
stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceProxy.java
stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/metadata/umdm/ServiceMetaData.java
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/pom.xml
stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
Log:
Merged revisions 15670,15676-15677 via svnmerge from
https://svn.jboss.org/repos/jbossws/stack/native/trunk
.......
r15670 | ropalka | 2012-02-16 15:04:49 +0100 (Thu, 16 Feb 2012) | 1 line
[JBWS-3438] make JAX-RPC generated proxies to be de/serializable
.......
r15676 | ropalka | 2012-02-17 12:33:36 +0100 (Fri, 17 Feb 2012) | 1 line
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
.......
r15677 | ropalka | 2012-02-17 12:34:20 +0100 (Fri, 17 Feb 2012) | 1 line
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
.......
Property changes on: stack/native/branches/jbossws-native-4.0.x
___________________________________________________________________
Modified: svnmerge-integrated
- https://svn.jboss.org/repos/jbossws/stack/native/trunk:1-15635,15653
+ https://svn.jboss.org/repos/jbossws/stack/native/trunk:1-15651,15653-15678
Modified: svn:mergeinfo
- /stack/native/branches/asoldano:14057,14069
/stack/native/branches/ropalka:13836-13879
/stack/native/trunk:15653
+ /stack/native/branches/asoldano:14057,14069
/stack/native/branches/ropalka:13836-13879
/stack/native/trunk:15653,15670-15677
Modified: stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceImpl.java
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceImpl.java 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceImpl.java 2012-02-17 12:07:13 UTC (rev 15679)
@@ -21,6 +21,11 @@
*/
package org.jboss.ws.core.jaxrpc.client;
+import java.io.Externalizable;
+import java.io.IOException;
+import java.io.ObjectInput;
+import java.io.ObjectOutput;
+import java.io.Serializable;
import java.lang.reflect.Proxy;
import java.net.URL;
import java.rmi.Remote;
@@ -73,30 +78,38 @@
* @author Thomas.Diesler(a)jboss.org
* @since 10-Oct-2004
*/
-public class ServiceImpl implements ServiceExt
+public class ServiceImpl implements ServiceExt, Serializable, Externalizable
{
private static final ResourceBundle bundle = BundleUtils.getBundle(ServiceImpl.class);
// provide logging
private static final Logger log = Logger.getLogger(ServiceImpl.class);
// The service meta data that is associated with this JAXRPC Service
- private ServiceMetaData serviceMetaData;
+ private transient ServiceMetaData serviceMetaData;
+ private QName serviceName;
// The optional WSDL location
private URL wsdlLocation;
+ private URL mappingURL;
+ private URL securityURL;
+ private JavaWsdlMapping mappingConfig;
+ private WSSecurityConfiguration securityConfig;
// The <service-ref> meta data
private UnifiedServiceRefMetaData usrMetaData;
// The handler registry
- private HandlerRegistryImpl handlerRegistry;
+ private transient HandlerRegistryImpl handlerRegistry;
+ public ServiceImpl() {
+ // for deserialization only
+ }
+
/**
* Construct a Service without WSDL meta data
*/
public ServiceImpl(QName serviceName)
{
- UnifiedMetaData wsMetaData = new UnifiedMetaData(new ResourceLoaderAdapter());
- serviceMetaData = new ServiceMetaData(wsMetaData, serviceName);
- handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ this.serviceName = serviceName;
+ init();
}
/**
@@ -104,13 +117,11 @@
*/
public ServiceImpl(QName serviceName, URL wsdlURL, URL mappingURL, URL securityURL)
{
+ this.serviceName = serviceName;
this.wsdlLocation = wsdlURL;
- JAXRPCClientMetaDataBuilder builder = new JAXRPCClientMetaDataBuilder();
-
- ClassLoader ctxClassLoader = SecurityActions.getContextClassLoader();
-
- serviceMetaData = builder.buildMetaData(serviceName, wsdlURL, mappingURL, securityURL, null, ctxClassLoader);
- handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ this.mappingURL = mappingURL;
+ this.securityURL = securityURL;
+ init();
}
/**
@@ -118,16 +129,55 @@
*/
public ServiceImpl(QName serviceName, URL wsdlURL, JavaWsdlMapping mappingURL, WSSecurityConfiguration securityConfig, UnifiedServiceRefMetaData usrMetaData)
{
+ this.serviceName = serviceName;
this.wsdlLocation = wsdlURL;
+ this.mappingConfig = mappingURL;
+ this.securityConfig = securityConfig;
this.usrMetaData = usrMetaData;
+ init();
+ }
- JAXRPCClientMetaDataBuilder builder = new JAXRPCClientMetaDataBuilder();
- ClassLoader ctxClassLoader = SecurityActions.getContextClassLoader();
+ public void writeExternal(final ObjectOutput out) throws IOException {
+ out.writeObject(serviceName);
+ out.writeObject(wsdlLocation);
+ out.writeObject(mappingURL);
+ out.writeObject(securityURL);
+ out.writeObject(mappingConfig);
+ out.writeObject(securityConfig);
+ out.writeObject(usrMetaData);
+ }
- serviceMetaData = builder.buildMetaData(serviceName, wsdlURL, mappingURL, securityConfig, usrMetaData, ctxClassLoader);
- handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ public void readExternal(final ObjectInput in) throws IOException, ClassNotFoundException {
+ serviceName = (QName)in.readObject();
+ wsdlLocation = (URL)in.readObject();
+ mappingURL = (URL)in.readObject();
+ securityURL = (URL)in.readObject();
+ mappingConfig = (JavaWsdlMapping)in.readObject();
+ securityConfig = (WSSecurityConfiguration)in.readObject();
+ usrMetaData = (UnifiedServiceRefMetaData)in.readObject();
+ init();
}
+ private void init() {
+ if ((wsdlLocation == null) && (mappingURL == null) && (securityURL == null) && (securityConfig == null) && (mappingConfig == null) && (usrMetaData == null)) {
+ UnifiedMetaData wsMetaData = new UnifiedMetaData(new ResourceLoaderAdapter());
+ serviceMetaData = new ServiceMetaData(wsMetaData, serviceName);
+ handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ return;
+ }
+ if ((mappingURL != null) || (securityURL != null)) {
+ JAXRPCClientMetaDataBuilder builder = new JAXRPCClientMetaDataBuilder();
+ ClassLoader ctxClassLoader = SecurityActions.getContextClassLoader();
+ serviceMetaData = builder.buildMetaData(serviceName, wsdlLocation, mappingURL, securityURL, null, ctxClassLoader);
+ handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ return;
+ }
+ JAXRPCClientMetaDataBuilder builder = new JAXRPCClientMetaDataBuilder();
+ ClassLoader ctxClassLoader = SecurityActions.getContextClassLoader();
+ serviceMetaData = builder.buildMetaData(serviceName, wsdlLocation, mappingConfig, securityConfig, usrMetaData, ctxClassLoader);
+ handlerRegistry = new HandlerRegistryImpl(serviceMetaData);
+ }
+
public ServiceMetaData getServiceMetaData()
{
return serviceMetaData;
Modified: stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceProxy.java
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceProxy.java 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/core/jaxrpc/client/ServiceProxy.java 2012-02-17 12:07:13 UTC (rev 15679)
@@ -21,6 +21,11 @@
*/
package org.jboss.ws.core.jaxrpc.client;
+import java.io.Externalizable;
+import java.io.IOException;
+import java.io.ObjectInput;
+import java.io.ObjectOutput;
+import java.io.Serializable;
import java.lang.reflect.InvocationHandler;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
@@ -44,7 +49,7 @@
* @author Thomas.Diesler(a)jboss.org
* @since 15-May-2004
*/
-public class ServiceProxy implements InvocationHandler
+public class ServiceProxy implements InvocationHandler, Serializable, Externalizable
{
private static final ResourceBundle bundle = BundleUtils.getBundle(ServiceProxy.class);
// provide logging
@@ -52,17 +57,22 @@
// The underlying jaxrpc service
private ServiceImpl jaxrpcService;
+ private Class siClass;
// The methods from java.lang.Object
- private List objectMethods = new ArrayList();
+ private transient List objectMethods = new ArrayList();
// The methods from javax.xml.rpc.Service
- private List jaxrpcServiceMethods = new ArrayList();
+ private transient List jaxrpcServiceMethods = new ArrayList();
// The methods from the service interface, in case of javax.xml.rpc.Service it is empty
- private List serviceInterfaceMethods = new ArrayList();
+ private transient List serviceInterfaceMethods = new ArrayList();
// The cached getPort method
- private Method getPortMethod;
+ private transient Method getPortMethod;
+ public ServiceProxy() {
+ // for deserialization only
+ }
+
/**
* Construct a client side service proxy.
* <p/>
@@ -74,26 +84,30 @@
public ServiceProxy(ServiceImpl service, Class siClass)
{
this.jaxrpcService = service;
+ this.siClass = siClass;
+ init();
+ }
- // initialize java.lang.Object methods
- objectMethods.addAll(Arrays.asList(Object.class.getMethods()));
+ private void init() {
+ // initialize java.lang.Object methods
+ objectMethods.addAll(Arrays.asList(Object.class.getMethods()));
- // initialize javax.xml.rpc.Service methods
- jaxrpcServiceMethods.addAll(Arrays.asList(ServiceExt.class.getMethods()));
+ // initialize javax.xml.rpc.Service methods
+ jaxrpcServiceMethods.addAll(Arrays.asList(ServiceExt.class.getMethods()));
- // initialize SI methods
- if (siClass.getName().equals("javax.xml.rpc.Service") == false)
- serviceInterfaceMethods.addAll(Arrays.asList(siClass.getDeclaredMethods()));
+ // initialize SI methods
+ if (siClass.getName().equals("javax.xml.rpc.Service") == false)
+ serviceInterfaceMethods.addAll(Arrays.asList(siClass.getDeclaredMethods()));
- // initialize special ws4ee methods
- try
- {
- getPortMethod = Service.class.getMethod("getPort", new Class[]{Class.class});
- }
- catch (NoSuchMethodException e)
- {
- throw new JAXRPCException(e.toString());
- }
+ // initialize special ws4ee methods
+ try
+ {
+ getPortMethod = Service.class.getMethod("getPort", new Class[]{Class.class});
+ }
+ catch (NoSuchMethodException e)
+ {
+ throw new JAXRPCException(e.toString());
+ }
}
/**
@@ -159,4 +173,16 @@
log.error(BundleUtils.getMessage(bundle, "SERVICE_ERROR"), th);
throw th;
}
+
+ public void writeExternal(final ObjectOutput out) throws IOException {
+ out.writeObject(jaxrpcService);
+ out.writeObject(siClass);
+ }
+
+ public void readExternal(final ObjectInput in) throws IOException, ClassNotFoundException {
+ jaxrpcService = (ServiceImpl)in.readObject();
+ siClass = (Class)in.readObject();
+ init();
+ }
+
}
Modified: stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/metadata/umdm/ServiceMetaData.java
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/metadata/umdm/ServiceMetaData.java 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/core/src/main/java/org/jboss/ws/metadata/umdm/ServiceMetaData.java 2012-02-17 12:07:13 UTC (rev 15679)
@@ -22,6 +22,7 @@
package org.jboss.ws.metadata.umdm;
import java.io.IOException;
+import java.io.Serializable;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.ArrayList;
@@ -60,7 +61,7 @@
* @author Thomas.Diesler(a)jboss.org
* @since 12-May-2005
*/
-public class ServiceMetaData implements InitalizableMetaData
+public class ServiceMetaData implements InitalizableMetaData, Serializable
{
private static final ResourceBundle bundle = BundleUtils.getBundle(ServiceMetaData.class);
// provide logging
Copied: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties (from rev 15677, stack/native/trunk/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties)
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jndi.properties
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jndi.properties 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Copied: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/server.jndi.properties (from rev 15677, stack/native/trunk/modules/testsuite/native-tests/src/test/etc/server.jndi.properties)
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/native-tests/src/test/etc/server.jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Modified: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/pom.xml
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/pom.xml 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/pom.xml 2012-02-17 12:07:13 UTC (rev 15679)
@@ -127,6 +127,7 @@
<!-- copy etc files -->
<testResource>
<directory>src/test/etc</directory>
+ <filtering>true</filtering>
</testResource>
<!-- copy handler definitions -->
<testResource>
@@ -267,10 +268,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -980,11 +977,6 @@
</exclusions>
</dependency>
<dependency>
- <groupId>org.jboss.naming</groupId>
- <artifactId>jnp-client</artifactId>
- <version>5.0.5.Final</version>
- </dependency>
- <dependency>
<groupId>org.picketbox</groupId>
<artifactId>jbosssx-client</artifactId>
<version>3.0.0.CR2</version>
Copied: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (from rev 15677, stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties)
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 11:36:22 UTC (rev 15678)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Copied: stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (from rev 15677, stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties)
===================================================================
--- stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/native/branches/jbossws-native-4.0.x/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties 2012-02-17 12:07:13 UTC (rev 15679)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
12 years, 10 months
JBossWS SVN: r15678 - in shared-testsuite/trunk: testsuite/src/test/java/org/jboss/test/ws/jaxws/jbws1841 and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 06:36:22 -0500 (Fri, 17 Feb 2012)
New Revision: 15678
Modified:
shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/JBossWSTest.java
shared-testsuite/trunk/testsuite/src/test/java/org/jboss/test/ws/jaxws/jbws1841/JBWS1841TestCase.java
Log:
[JBWS-3435] split jndi properties
Modified: shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/JBossWSTest.java
===================================================================
--- shared-testsuite/trunk/testsuite/src/test/java/org/jboss/test/ws/jaxws/jbws1841/JBWS1841TestCase.java 2012-02-17 11:34:20 UTC (rev 15677)
+++ shared-testsuite/trunk/testsuite/src/test/java/org/jboss/test/ws/jaxws/jbws1841/JBWS1841TestCase.java 2012-02-17 11:36:22 UTC (rev 15678)
@@ -57,7 +57,7 @@
QName serviceName = new QName("http://www.openuri.org/2004/04/HelloWorld", "EndpointService");
port = Service.create(wsdlURL, serviceName).getPort(EndpointInterface.class);
- InitialContext ctx = new InitialContext();
+ InitialContext ctx = getInitialContext();
remote = (StatelessRemote)ctx.lookup(getRemoteEjbJndiName());
}
}
12 years, 10 months
JBossWS SVN: r15677 - stack/native/trunk/modules/testsuite/shared-tests/src/test/etc.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 06:34:20 -0500 (Fri, 17 Feb 2012)
New Revision: 15677
Added:
stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
Removed:
stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties
Modified:
stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
Log:
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
Added: stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties 2012-02-17 11:34:20 UTC (rev 15677)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:33:36 UTC (rev 15676)
+++ stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:34:20 UTC (rev 15677)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 11:33:36 UTC (rev 15676)
+++ stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 11:34:20 UTC (rev 15677)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Added: stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/native/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties 2012-02-17 11:34:20 UTC (rev 15677)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
12 years, 10 months
JBossWS SVN: r15676 - in stack/native/trunk/modules/testsuite: native-tests/src/test/etc and 1 other directory.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 06:33:36 -0500 (Fri, 17 Feb 2012)
New Revision: 15676
Added:
stack/native/trunk/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties
stack/native/trunk/modules/testsuite/native-tests/src/test/etc/server.jndi.properties
Removed:
stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jndi.properties
Modified:
stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties
stack/native/trunk/modules/testsuite/pom.xml
Log:
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
Added: stack/native/trunk/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/native/trunk/modules/testsuite/native-tests/src/test/etc/appclient.jndi.properties 2012-02-17 11:33:36 UTC (rev 15676)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:32:54 UTC (rev 15675)
+++ stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:33:36 UTC (rev 15676)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
+++ stack/native/trunk/modules/testsuite/native-tests/src/test/etc/jndi.properties 2012-02-17 11:33:36 UTC (rev 15676)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Added: stack/native/trunk/modules/testsuite/native-tests/src/test/etc/server.jndi.properties
===================================================================
--- stack/native/trunk/modules/testsuite/native-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/native/trunk/modules/testsuite/native-tests/src/test/etc/server.jndi.properties 2012-02-17 11:33:36 UTC (rev 15676)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Modified: stack/native/trunk/modules/testsuite/pom.xml
===================================================================
--- stack/native/trunk/modules/testsuite/pom.xml 2012-02-17 11:32:54 UTC (rev 15675)
+++ stack/native/trunk/modules/testsuite/pom.xml 2012-02-17 11:33:36 UTC (rev 15676)
@@ -127,6 +127,7 @@
<!-- copy etc files -->
<testResource>
<directory>src/test/etc</directory>
+ <filtering>true</filtering>
</testResource>
<!-- copy handler definitions -->
<testResource>
@@ -267,10 +268,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -980,11 +977,6 @@
</exclusions>
</dependency>
<dependency>
- <groupId>org.jboss.naming</groupId>
- <artifactId>jnp-client</artifactId>
- <version>5.0.5.Final</version>
- </dependency>
- <dependency>
<groupId>org.picketbox</groupId>
<artifactId>jbosssx-client</artifactId>
<version>3.0.0.CR2</version>
12 years, 10 months
JBossWS SVN: r15675 - in stack/cxf/trunk/modules/testsuite: cxf-spring-tests/src/test/etc and 2 other directories.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-17 06:32:54 -0500 (Fri, 17 Feb 2012)
New Revision: 15675
Added:
stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties
stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties
stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties
stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties
stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
Removed:
stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties
stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jndi.properties
stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties
Modified:
stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties
stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties
stack/cxf/trunk/modules/testsuite/pom.xml
stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
Log:
[JBWS-3435] make jndi & ejb client properties up2date. Also fixing host name filtering
Added: stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/appclient.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Added: stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/cxf-spring-tests/src/test/etc/server.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Added: stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/appclient.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jndi.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Added: stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/cxf-tests/src/test/etc/server.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
Modified: stack/cxf/trunk/modules/testsuite/pom.xml
===================================================================
--- stack/cxf/trunk/modules/testsuite/pom.xml 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/pom.xml 2012-02-17 11:32:54 UTC (rev 15675)
@@ -135,6 +135,7 @@
<!-- copy etc files -->
<testResource>
<directory>src/test/etc</directory>
+ <filtering>true</filtering>
</testResource>
<!-- copy handler definitions -->
<testResource>
@@ -265,10 +266,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -359,10 +356,6 @@
<value>${jboss.bind.address}</value>
</property>
<property>
- <name>java.naming.provider.url</name>
- <value>jnp://${jboss.bind.address}:1099</value>
- </property>
- <property>
<name>java.protocol.handler.pkgs</name>
<value>org.jboss.net.protocol|org.jboss.vfs.protocol|org.jboss.virtual.protocol</value>
</property>
@@ -1168,11 +1161,6 @@
</exclusions>
</dependency>
<dependency>
- <groupId>org.jboss.naming</groupId>
- <artifactId>jnp-client</artifactId>
- <version>5.0.5.Final</version>
- </dependency>
- <dependency>
<groupId>org.jboss.ejb3</groupId>
<artifactId>jboss-ejb3-ext-api</artifactId>
<version>2.0.0-beta-1</version>
Added: stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/appclient.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4448
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
Modified: stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jboss-ejb-client.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,30 +1,5 @@
-#
-# JBoss, Home of Professional Open Source.
-# Copyright 2011, Red Hat, Inc., and individual contributors
-# as indicated by the @author tags. See the copyright.txt file in the
-# distribution for a full listing of individual contributors.
-#
-# This is free software; you can redistribute it and/or modify it
-# under the terms of the GNU Lesser General Public License as
-# published by the Free Software Foundation; either version 2.1 of
-# the License, or (at your option) any later version.
-#
-# This software is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
-# Lesser General Public License for more details.
-#
-# You should have received a copy of the GNU Lesser General Public
-# License along with this software; if not, write to the Free
-# Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
-# 02110-1301 USA, or see the FSF site: http://www.fsf.org.
-#
remote.connectionprovider.create.options.org.xnio.Options.SSL_ENABLED=false
-
remote.connections=default
-
-remote.connection.default.host=localhost
+remote.connection.default.host=(a)jboss.bind.address@
remote.connection.default.port=4447
remote.connection.default.connect.options.org.xnio.Options.SASL_POLICY_NOANONYMOUS=false
-
-
Deleted: stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-16 15:24:58 UTC (rev 15674)
+++ stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -1,3 +0,0 @@
-java.naming.factory.initial=org.jnp.interfaces.NamingContextFactory
-java.naming.factory.url.pkgs=org.jboss.naming:org.jnp.interfaces:org.jboss.ejb.client.naming
-java.naming.provider.url=jnp://@jboss.bind.address@:1099
\ No newline at end of file
Added: stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties
===================================================================
--- stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties (rev 0)
+++ stack/cxf/trunk/modules/testsuite/shared-tests/src/test/etc/server.jndi.properties 2012-02-17 11:32:54 UTC (rev 15675)
@@ -0,0 +1,5 @@
+java.naming.factory.initial=org.jboss.naming.remote.client.InitialContextFactory
+java.naming.factory.url.pkgs=org.jboss.ejb.client.naming:org.jboss.naming.remote.client
+java.naming.provider.url=remote://@jboss.bind.address@:4447
+jboss.naming.client.connect.options.org.xnio.Options.SASL_POLICY_NOPLAINTEXT=false
+jboss.naming.client.security.callback.handler.class=org.jboss.wsf.test.CallbackHandler
\ No newline at end of file
12 years, 10 months
JBossWS SVN: r15674 - stack/cxf/trunk.
by jbossws-commits@lists.jboss.org
Author: alessio.soldano(a)jboss.com
Date: 2012-02-16 10:24:58 -0500 (Thu, 16 Feb 2012)
New Revision: 15674
Modified:
stack/cxf/trunk/pom.xml
Log:
[JBWS-3439] Moving to santuario 1.5.0 and wss4j 1.6.5-SNAPSHOT
Modified: stack/cxf/trunk/pom.xml
===================================================================
--- stack/cxf/trunk/pom.xml 2012-02-16 14:22:28 UTC (rev 15673)
+++ stack/cxf/trunk/pom.xml 2012-02-16 15:24:58 UTC (rev 15674)
@@ -103,8 +103,8 @@
<jms.api.version>1.0.0.Final</jms.api.version>
<velocity.version>1.5</velocity.version>
<xerces.version>2.9.1</xerces.version>
- <xmlsec.version>1.4.5</xmlsec.version>
- <wss4j.version>1.6.4</wss4j.version>
+ <xmlsec.version>1.5.0</xmlsec.version>
+ <wss4j.version>1.6.5-SNAPSHOT</wss4j.version>
<wstx.version>3.2.9</wstx.version>
<spring.version>3.0.6.RELEASE</spring.version>
</properties>
12 years, 10 months
JBossWS SVN: r15673 - shared-testsuite/trunk.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-16 09:22:28 -0500 (Thu, 16 Feb 2012)
New Revision: 15673
Modified:
shared-testsuite/trunk/pom.xml
Log:
fix shared-testsuite version
Modified: shared-testsuite/trunk/pom.xml
===================================================================
--- shared-testsuite/trunk/pom.xml 2012-02-16 14:19:08 UTC (rev 15672)
+++ shared-testsuite/trunk/pom.xml 2012-02-16 14:22:28 UTC (rev 15673)
@@ -6,7 +6,7 @@
<artifactId>jbossws-shared-testsuite</artifactId>
<description>JBossWS Stack Agnostic Testsuite</description>
- <version>4.0.1-SNAPSHOT</version>
+ <version>4.0.2-SNAPSHOT</version>
<!-- Parent -->
<parent>
12 years, 10 months
JBossWS SVN: r15672 - shared-testsuite/trunk/src/main/java/org/jboss/wsf/test.
by jbossws-commits@lists.jboss.org
Author: ropalka
Date: 2012-02-16 09:19:08 -0500 (Thu, 16 Feb 2012)
New Revision: 15672
Added:
shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/CallbackHandler.java
Log:
port callback handler from AS7
Added: shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/CallbackHandler.java
===================================================================
--- shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/CallbackHandler.java (rev 0)
+++ shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/CallbackHandler.java 2012-02-16 14:19:08 UTC (rev 15672)
@@ -0,0 +1,49 @@
+/*
+ * JBoss, Home of Professional Open Source
+ * Copyright 2012 Red Hat Inc. and/or its affiliates and other contributors
+ * as indicated by the @authors tag. All rights reserved.
+ * See the copyright.txt in the distribution for a
+ * full listing of individual contributors.
+ *
+ * This copyrighted material is made available to anyone wishing to use,
+ * modify, copy, or redistribute it subject to the terms and conditions
+ * of the GNU Lesser General Public License, v. 2.1.
+ * This program is distributed in the hope that it will be useful, but WITHOUT A
+ * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A
+ * PARTICULAR PURPOSE. See the GNU Lesser General Public License for more details.
+ * You should have received a copy of the GNU Lesser General Public License,
+ * v.2.1 along with this distribution; if not, write to the Free Software
+ * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02110-1301, USA.
+ */
+package org.jboss.wsf.test;
+
+import java.io.IOException;
+
+import javax.security.auth.callback.Callback;
+import javax.security.auth.callback.NameCallback;
+import javax.security.auth.callback.UnsupportedCallbackException;
+import javax.security.sasl.RealmCallback;
+
+/**
+ * @author <a href="mailto:ropalka@redhat.com">Richard Opalka</a>
+ */
+public final class CallbackHandler implements javax.security.auth.callback.CallbackHandler
+{
+ @Override
+ public void handle(final Callback[] callbacks) throws IOException, UnsupportedCallbackException
+ {
+ for (final Callback current : callbacks)
+ {
+ if(current instanceof NameCallback)
+ {
+ ((NameCallback) current).setName("$local");
+ }
+ else if (current instanceof RealmCallback)
+ {
+ ((RealmCallback) current).setText(((RealmCallback) current).getDefaultText());
+ }
+ }
+ }
+}
+
12 years, 10 months
--- shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/JBossWSTest.java 2012-02-17 11:34:20 UTC (rev 15677)
+++ shared-testsuite/trunk/src/main/java/org/jboss/wsf/test/JBossWSTest.java 2012-02-17 11:36:22 UTC (rev 15678)
@@ -23,6 +23,7 @@
import java.io.File;
import java.io.IOException;
+import java.io.InputStream;
import java.io.OutputStream;
import java.net.MalformedURLException;
import java.net.URL;
@@ -33,6 +34,9 @@
import java.util.LinkedList;
import java.util.List;
import java.util.Map;
+import java.util.Map.Entry;
+import java.util.Properties;
+import java.util.Set;
import java.util.StringTokenizer;
import javax.management.MBeanServerConnection;
@@ -277,25 +281,56 @@
return new File(parent, filename);
}
- /** Get the client's env context for a given name.
+ private static Hashtable<String, String> getEnvironment(final String resourceName) throws IOException {
+ final Hashtable<String, String> env = new Hashtable<String, String>();
+ final InputStream is = JBossWSTest.class.getClassLoader().getResourceAsStream(resourceName);
+ if (is != null) {
+ final Properties props = new Properties();
+ props.load(is);
+ Entry<Object, Object> entry;
+ final Iterator<Entry<Object, Object>> entries = props.entrySet().iterator();
+ while (entries.hasNext()) {
+ entry = entries.next();
+ env.put((String)entry.getKey(), (String)entry.getValue());
+ }
+ }
+ return env;
+ }
+
+ /** Get the appclient remote env context
*/
- @SuppressWarnings({ "unchecked", "rawtypes" })
- protected static InitialContext getInitialContext(String clientName) throws NamingException
+ protected static InitialContext getAppclientInitialContext() throws NamingException, IOException
{
- InitialContext iniCtx = new InitialContext();
- Hashtable env = iniCtx.getEnvironment();
- env.put(Context.URL_PKG_PREFIXES, "org.jboss.naming.client");
- env.put("j2ee.clientName", clientName);
- return new InitialContext(env);
+// InitialContext iniCtx = new InitialContext();
+// Hashtable env = iniCtx.getEnvironment();
+// env.put(Context.PROVIDER_URL, "remote://" + JBossWSTestHelper.getServerHost() + ":4448");
+// return new InitialContext(env);
+ final Hashtable<String, String> env = getEnvironment("appclient.jndi.properties");
+ return new InitialContext(env);
}
/** Get the client's env context
*/
- protected static InitialContext getInitialContext() throws NamingException
+ protected static InitialContext getServerInitialContext() throws NamingException, IOException
{
- return getInitialContext("jbossws-client");
+ final Hashtable<String, String> env = getEnvironment("server.jndi.properties");
+ return new InitialContext(env);
}
+ // TODO: remove
+ @Deprecated
+ protected static InitialContext getInitialContext(String s) throws NamingException, IOException
+ {
+ return getServerInitialContext();
+ }
+
+ // TODO: remove
+ @Deprecated
+ protected static InitialContext getInitialContext() throws NamingException, IOException
+ {
+ return getServerInitialContext();
+ }
+
public static void assertEquals(Element expElement, Element wasElement, boolean ignoreWhitespace)
{
normalizeWhitespace(expElement, ignoreWhitespace);
@@ -277,25 +281,56 @@
}
- /** Get the client's env context
+ /** Get the server remote env context
*/
Modified: shared-testsuite/trunk/testsuite/src/test/java/org/jboss/test/ws/jaxws/jbws1841/JBWS1841TestCase.java
===================================================================